@@ -16,9 +16,10 @@ import ipaddress
 import openstack
 from openstack.connection import exceptions as openstack_exc
 from oslo_log import log
-import retrying
+import tenacity
+from tenacity import retry
 
-from ironic.api.controllers.v1 import types
+from ironic.api.controllers.v1 import utils as api_utils
 from ironic.common import context as ironic_context
 from ironic.common import exception
 from ironic.common.i18n import _
@@ -344,8 +345,7 @@ def add_ports_to_network(task, network_uuid, security_groups=None):
                 wait_for_host_agent(
                     client, update_port_attrs['binding:host_id'])
             port = client.create_port(**port_attrs)
-            port = update_neutron_port(task.context, port.id,
-                                       update_port_attrs)
+            update_neutron_port(task.context, port.id, update_port_attrs)
             if CONF.neutron.dhcpv6_stateful_address_count > 1:
                 _add_ip_addresses_for_ipv6_stateful(task.context, port, client)
             if is_smart_nic:
@@ -719,13 +719,21 @@ def validate_port_info(node, port):
                     "in the nodes %(node)s port %(port)s",
                     {'node': node.uuid, 'port': port.uuid})
         return False
-    if (port.is_smartnic and not types.locallinkconnectiontype
-            .validate_for_smart_nic(port.local_link_connection)):
+
+    try:
+        api_utils.LOCAL_LINK_SMART_NIC_VALIDATOR(
+            'local_link_connection', port.local_link_connection)
+    except exception.Invalid:
+        valid_smart_nic = False
+    else:
+        valid_smart_nic = True
+
+    if port.is_smartnic and not valid_smart_nic:
         LOG.error("Smart NIC port must have port_id and hostname in "
                   "local_link_connection, port: %s", port['id'])
         return False
-    if (not port.is_smartnic and types.locallinkconnectiontype
-            .validate_for_smart_nic(port.local_link_connection)):
+
+    if not port.is_smartnic and valid_smart_nic:
         LOG.error("Only Smart NIC ports can have port_id and hostname "
                   "in local_link_connection, port: %s", port['id'])
         return False
@@ -858,11 +866,11 @@ def get_physnets_by_port_uuid(client, port_uuid):
                 if network.provider_physical_network else set())
 
 
-@retrying.retry(
-    stop_max_attempt_number=CONF.agent.neutron_agent_max_attempts,
-    retry_on_exception=lambda e: isinstance(e, exception.NetworkError),
-    wait_fixed=CONF.agent.neutron_agent_status_retry_interval * 1000
-)
+@retry(
+    retry=tenacity.retry_if_exception_type(exception.NetworkError),
+    stop=tenacity.stop_after_attempt(CONF.agent.neutron_agent_max_attempts),
+    wait=tenacity.wait_fixed(CONF.agent.neutron_agent_status_retry_interval),
+    reraise=True)
 def wait_for_host_agent(client, host_id, target_state='up'):
     """Wait for neutron agent to become target state
 
@@ -897,11 +905,11 @@ def wait_for_host_agent(client, host_id, target_state='up'):
             'host': host_id, 'state': target_state})
 
 
-@retrying.retry(
-    stop_max_attempt_number=CONF.agent.neutron_agent_max_attempts,
-    retry_on_exception=lambda e: isinstance(e, exception.NetworkError),
-    wait_fixed=CONF.agent.neutron_agent_status_retry_interval * 1000
-)
+@retry(
+    retry=tenacity.retry_if_exception_type(exception.NetworkError),
+    stop=tenacity.stop_after_attempt(CONF.agent.neutron_agent_max_attempts),
+    wait=tenacity.wait_fixed(CONF.agent.neutron_agent_status_retry_interval),
+    reraise=True)
 def wait_for_port_status(client, port_id, status):
     """Wait for port status to be the desired status
 
