@@ -420,7 +420,6 @@ deprecated_bios_disable_cleaning = policy.DeprecatedRule(
     deprecated_since=versionutils.deprecated.WALLABY
 )
 
-
 node_policies = [
     policy.DocumentedRuleDefault(
         name='baremetal:node:create',
@@ -770,6 +769,26 @@ node_policies = [
         ],
         deprecated_rule=deprecated_node_set_power_state
     ),
+    policy.DocumentedRuleDefault(
+        name='baremetal:node:set_boot_mode',
+        check_str=SYSTEM_OR_PROJECT_MEMBER,
+        scope_types=['system', 'project'],
+        description='Change Node boot mode',
+        operations=[
+            {'path': '/nodes/{node_ident}/states/boot_mode', 'method': 'PUT'}
+        ],
+        deprecated_rule=deprecated_node_set_power_state
+    ),
+    policy.DocumentedRuleDefault(
+        name='baremetal:node:set_secure_boot',
+        check_str=SYSTEM_OR_PROJECT_MEMBER,
+        scope_types=['system', 'project'],
+        description='Change Node secure boot state',
+        operations=[
+            {'path': '/nodes/{node_ident}/states/secure_boot', 'method': 'PUT'}
+        ],
+        deprecated_rule=deprecated_node_set_power_state
+    ),
     policy.DocumentedRuleDefault(
         name='baremetal:node:set_provision_state',
         check_str=SYSTEM_OR_OWNER_MEMBER_AND_LESSEE_ADMIN,
@@ -891,6 +910,24 @@ node_policies = [
         ],
         deprecated_rule=deprecated_bios_disable_cleaning
     ),
+    policy.DocumentedRuleDefault(
+        name='baremetal:node:history:get',
+        check_str=SYSTEM_OR_OWNER_READER,
+        scope_types=['system', 'project'],
+        description='Filter to allow operators to retreive history records '
+                    'for a node.',
+        operations=[
+            {'path': '/nodes/{node_ident}/history', 'method': 'GET'},
+            {'path': '/nodes/{node_ident}/history/{event_ident}',
+             'method': 'GET'}
+        ],
+        # This rule fallsback to deprecated_node_get in order to provide a
+        # mechanism so the additional policies only engage in an updated
+        # operating context.
+        deprecated_rule=deprecated_node_get
+    ),
+
+
 ]
 
 deprecated_port_reason = """
