@@ -370,13 +370,34 @@ RELEASE_MAPPING = {
             'VolumeTarget': ['1.0'],
         }
     },
-    'master': {
-        'api': '1.75',
-        'rpc': '1.54',
+    '18.2': {
+        'api': '1.78',
+        'rpc': '1.55',
         'objects': {
             'Allocation': ['1.1'],
             'BIOSSetting': ['1.1'],
             'Node': ['1.36', '1.35'],
+            'NodeHistory': ['1.0'],
+            'Conductor': ['1.3'],
+            'Chassis': ['1.3'],
+            'Deployment': ['1.0'],
+            'DeployTemplate': ['1.1'],
+            'Port': ['1.10'],
+            'Portgroup': ['1.4'],
+            'Trait': ['1.0'],
+            'TraitList': ['1.0'],
+            'VolumeConnector': ['1.0'],
+            'VolumeTarget': ['1.0'],
+        }
+    },
+    'master': {
+        'api': '1.78',
+        'rpc': '1.55',
+        'objects': {
+            'Allocation': ['1.1'],
+            'BIOSSetting': ['1.1'],
+            'Node': ['1.36', '1.35'],
+            'NodeHistory': ['1.0'],
             'Conductor': ['1.3'],
             'Chassis': ['1.3'],
             'Deployment': ['1.0'],
@@ -404,9 +425,9 @@ RELEASE_MAPPING = {
 #
 #            There should be at most two named mappings here.
 
-# NOTE(mgoddard): remove victoria prior to the xena release.
-RELEASE_MAPPING['victoria'] = RELEASE_MAPPING['16.0']
+# NOTE(mgoddard): remove wallaby prior to the yoga release.
 RELEASE_MAPPING['wallaby'] = RELEASE_MAPPING['17.0']
+RELEASE_MAPPING['xena'] = RELEASE_MAPPING['18.2']
 
 # List of available versions with named versions first; 'master' is excluded.
 RELEASE_VERSIONS = sorted(set(RELEASE_MAPPING) - {'master'}, reverse=True)
