@@ -121,15 +121,22 @@ def _get_steps(task, interfaces, get_method, enabled=False,
     for interface in interfaces:
         interface = getattr(task.driver, interface)
         if interface:
-            interface_steps = [x for x in getattr(interface, get_method)(task)
-                               if not enabled or x['priority'] > 0]
+            # NOTE(janders) get all steps to start with, regardless of whether
+            # enabled is True and priority is zero or not; we need to apply
+            # priority overrides prior to filtering out disabled steps
+            interface_steps = [x for x in getattr(interface, get_method)(task)]
             steps.extend(interface_steps)
+    # Iterate over steps to apply prio overrides if set
     if prio_overrides is not None:
         for step in steps:
             override_key = '%(interface)s.%(step)s' % step
             override_value = prio_overrides.get(override_key)
             if override_value:
                 step["priority"] = int(override_value)
+    # NOTE(janders) If enabled is set to True, we filter out steps with zero
+    # priority now, after applying priority overrides
+    if enabled:
+        steps = [x for x in steps if not (x.get('priority') == 0)]
     if sort_step_key:
         steps = _sorted_steps(steps, sort_step_key)
     return steps
@@ -221,6 +228,11 @@ def set_node_cleaning_steps(task, disable_ramdisk=False):
         driver_internal_info['clean_steps'] = _validate_user_clean_steps(
             task, steps, disable_ramdisk=disable_ramdisk)
 
+    LOG.debug('List of the steps for %(type)s cleaning of node %(node)s: '
+              '%(steps)s', {'type': 'manual' if manual_clean else 'automated',
+                            'node': node.uuid,
+                            'steps': driver_internal_info['clean_steps']})
+
     node.clean_step = {}
     driver_internal_info['clean_step_index'] = None
     node.driver_internal_info = driver_internal_info
@@ -358,6 +370,10 @@ def set_node_deployment_steps(task, reset_current=True, skip_missing=False):
     driver_internal_info = node.driver_internal_info
     driver_internal_info['deploy_steps'] = _get_all_deployment_steps(
         task, skip_missing=skip_missing)
+
+    LOG.debug('List of the deploy steps for node %(node)s: '
+              '%(steps)s', {'node': node.uuid,
+                            'steps': driver_internal_info['deploy_steps']})
     if reset_current:
         node.deploy_step = {}
         driver_internal_info['deploy_step_index'] = None
