@@ -108,7 +108,7 @@ from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import excutils
 from oslo_utils import timeutils
-import retrying
+import tenacity
 
 from ironic.common import driver_factory
 from ironic.common import exception
@@ -206,6 +206,10 @@ class TaskManager(object):
 
         self.context = context
         self._node = None
+        self._ports = None
+        self._portgroups = None
+        self._volume_connectors = None
+        self._volume_targets = None
         self.node_id = node_id
         self.shared = shared
         self._retry = retry
@@ -233,13 +237,6 @@ class TaskManager(object):
                 self._debug_timer.restart()
                 self.node = node
 
-            self.ports = objects.Port.list_by_node_id(context, self.node.id)
-            self.portgroups = objects.Portgroup.list_by_node_id(context,
-                                                                self.node.id)
-            self.volume_connectors = objects.VolumeConnector.list_by_node_id(
-                context, self.node.id)
-            self.volume_targets = objects.VolumeTarget.list_by_node_id(
-                context, self.node.id)
             if load_driver:
                 self.driver = driver_factory.build_driver_for_task(self)
             else:
@@ -260,6 +257,67 @@ class TaskManager(object):
             self.fsm.initialize(start_state=self.node.provision_state,
                                 target_state=self.node.target_provision_state)
 
+    @property
+    def ports(self):
+        try:
+            if self._ports is None:
+                self._ports = objects.Port.list_by_node_id(self.context,
+                                                           self.node.id)
+        except Exception:
+            with excutils.save_and_reraise_exception():
+                self.release_resources()
+        return self._ports
+
+    @ports.setter
+    def ports(self, ports):
+        self._ports = ports
+
+    @property
+    def portgroups(self):
+        try:
+            if self._portgroups is None:
+                self._portgroups = objects.Portgroup.list_by_node_id(
+                    self.context, self.node.id)
+        except Exception:
+            with excutils.save_and_reraise_exception():
+                self.release_resources()
+        return self._portgroups
+
+    @portgroups.setter
+    def portgroups(self, portgroups):
+        self._portgroups = portgroups
+
+    @property
+    def volume_connectors(self):
+        try:
+            if self._volume_connectors is None:
+                self._volume_connectors = \
+                    objects.VolumeConnector.list_by_node_id(
+                        self.context, self.node.id)
+        except Exception:
+            with excutils.save_and_reraise_exception():
+                self.release_resources()
+        return self._volume_connectors
+
+    @volume_connectors.setter
+    def volume_connectors(self, volume_connectors):
+        self._volume_connectors = volume_connectors
+
+    @property
+    def volume_targets(self):
+        try:
+            if self._volume_targets is None:
+                self._volume_targets = objects.VolumeTarget.list_by_node_id(
+                    self.context, self.node.id)
+        except Exception:
+            with excutils.save_and_reraise_exception():
+                self.release_resources()
+        return self._volume_targets
+
+    @volume_targets.setter
+    def volume_targets(self, volume_targets):
+        self._volume_targets = volume_targets
+
     def load_driver(self):
         if self.driver is None:
             self.driver = driver_factory.build_driver_for_task(self)
@@ -268,19 +326,21 @@ class TaskManager(object):
         self._debug_timer.restart()
 
         if self._patient:
-            attempts = None
+            stop_after = tenacity.stop_never
         elif self._retry:
-            attempts = CONF.conductor.node_locked_retry_attempts
+            stop_after = tenacity.stop_after_attempt(
+                CONF.conductor.node_locked_retry_attempts)
         else:
-            attempts = 1
+            stop_after = tenacity.stop_after_attempt(1)
 
         # NodeLocked exceptions can be annoying. Let's try to alleviate
-        # some of that pain by retrying our lock attempts. The retrying
-        # module expects a wait_fixed value in milliseconds.
-        @retrying.retry(
-            retry_on_exception=lambda e: isinstance(e, exception.NodeLocked),
-            stop_max_attempt_number=attempts,
-            wait_fixed=CONF.conductor.node_locked_retry_interval * 1000)
+        # some of that pain by retrying our lock attempts.
+        @tenacity.retry(
+            retry=tenacity.retry_if_exception_type(exception.NodeLocked),
+            stop=stop_after,
+            wait=tenacity.wait_fixed(
+                CONF.conductor.node_locked_retry_interval),
+            reraise=True)
         def reserve_node():
             self.node = objects.Node.reserve(self.context, CONF.host,
                                              self.node_id)
@@ -300,8 +360,8 @@ class TaskManager(object):
         when provided with one.
 
         :param purpose: optionally change the purpose of the lock
-        :param retry: whether to retry locking if it fails, the class-level
-            value is used by default
+        :param retry: whether to retry locking if it fails, the
+            class-level value is used by default
         :raises: NodeLocked if an exclusive lock remains on the node after
                             "node_locked_retry_attempts"
         """
