@@ -17,6 +17,7 @@
 import os
 
 from oslo_config import cfg
+from oslo_config import types as cfg_types
 
 from ironic.common.i18n import _
 
@@ -100,8 +101,15 @@ opts = [
                       "creating files that cannot be read by the TFTP server. "
                       "Setting to <None> will result in the operating "
                       "system's umask to be utilized for the creation of new "
-                      "tftp folders. It is recommended that an octal "
+                      "tftp folders. It is required that an octal "
                       "representation is specified. For example: 0o755")),
+    cfg.IntOpt('file_permission',
+               default=0o644,
+               help=_('The permission which is used on files created as part '
+                      'of configuration and setup of file assets for PXE '
+                      'based operations. Defaults to a value of 0o644.'
+                      'This value must be specified as an octal '
+                      'representation. For example: 0o644')),
     cfg.StrOpt('pxe_bootfile_name',
                default='pxelinux.0',
                help=_('Bootfile DHCP parameter.')),
@@ -119,10 +127,10 @@ opts = [
                default='undionly.kpxe',
                help=_('Bootfile DHCP parameter.')),
     cfg.StrOpt('uefi_ipxe_bootfile_name',
-               default='ipxe.efi',
+               default='snponly.efi',
                help=_('Bootfile DHCP parameter for UEFI boot mode. If you '
                       'experience problems with booting using it, try '
-                      'snponly.efi.')),
+                      'ipxe.efi.')),
     cfg.DictOpt('pxe_bootfile_name_by_arch',
                 default={},
                 help=_('Bootfile DHCP parameter per node architecture. '
@@ -155,8 +163,10 @@ opts = [
                choices=[('4', _('IPv4')),
                         ('6', _('IPv6'))],
                mutable=True,
+               deprecated_for_removal=True,
                help=_('The IP version that will be used for PXE booting. '
-                      'Defaults to 4. EXPERIMENTAL')),
+                      'Defaults to 4. This option has been a no-op for in-tree'
+                      'drivers since the Ussuri development cycle.')),
     cfg.BoolOpt('ipxe_use_swift',
                 default=False,
                 mutable=True,
@@ -176,6 +186,19 @@ opts = [
                        'or with Redfish on machines that cannot do persistent '
                        'boot. Mostly useful for standalone ironic since '
                        'Neutron will prevent incorrect PXE boot.')),
+    cfg.Opt('loader_file_paths',
+            type=cfg_types.Dict(cfg_types.String(quotes=True)),
+            default={},
+            help=_('Dictionary describing the bootloaders to load into '
+                   'conductor PXE/iPXE boot folders values from the host '
+                   'operating system. Formatted as key of destination '
+                   'file name, and value of a full path to a file to be '
+                   'copied. File assets will have [pxe]file_permission '
+                   'applied, if set. If used, the file names should '
+                   'match established bootloader configuration settings '
+                   'for bootloaders. Use example: '
+                   'ipxe.efi:/usr/share/ipxe/ipxe-snponly-x86_64.efi,'
+                   'undionly.kpxe:/usr/share/ipxe/undionly.kpxe')),
 ]
 
 
