@@ -977,18 +977,6 @@ class Connection(object, metaclass=abc.ABCMeta):
                   of migrated objects.
         """
 
-    @abc.abstractmethod
-    def migrate_from_iscsi_deploy(self, context, max_count):
-        """Tries to migrate away from the iscsi deploy interface.
-
-        :param context: the admin context
-        :param max_count: The maximum number of objects to migrate. Must be
-                          >= 0. If zero, all the objects will be migrated.
-        :returns: A 2-tuple, 1. the total number of objects that need to be
-                  migrated (at the beginning of this call) and 2. the number
-                  of migrated objects.
-        """
-
     @abc.abstractmethod
     def set_node_traits(self, node_id, traits, version):
         """Replace all of the node traits with specified list of traits.
@@ -1070,10 +1058,12 @@ class Connection(object, metaclass=abc.ABCMeta):
                           {
                            'name': String,
                            'value': String,
+                           additional settings from BIOS registry
                           },
                           {
                            'name': String,
                            'value': String,
+                           additional settings from BIOS registry
                           },
                           ...
                         ]
@@ -1097,10 +1087,12 @@ class Connection(object, metaclass=abc.ABCMeta):
                           {
                            'name': String,
                            'value': String,
+                           additional settings from BIOS registry
                           },
                           {
                            'name': String,
                            'value': String,
+                           additional settings from BIOS registry
                           },
                           ...
                         ]
@@ -1330,3 +1322,79 @@ class Connection(object, metaclass=abc.ABCMeta):
         :param names: List of names to filter by.
         :returns: A list of deploy templates.
         """
+
+    @abc.abstractmethod
+    def create_node_history(self, values):
+        """Create a new history record.
+
+        :param values: Dict of values.
+        """
+
+    @abc.abstractmethod
+    def destroy_node_history_by_uuid(self, history_uuid):
+        """Destroy a history record.
+
+        :param history_uuid: The uuid of a history record
+        """
+
+    @abc.abstractmethod
+    def get_node_history_by_id(self, history_id):
+        """Return a node history representation.
+
+        :param history_id: The id of a history record.
+        :returns: A history.
+        """
+
+    @abc.abstractmethod
+    def get_node_history_by_uuid(self, history_uuid):
+        """Return a node history representation.
+
+        :param history_uuid: The uuid of a history record
+        :returns: A history.
+        """
+
+    @abc.abstractmethod
+    def get_node_history_list(self, limit=None, marker=None,
+                              sort_key=None, sort_dir=None):
+        """Return a list of node history records
+
+        :param limit: Maximum number of history records to return.
+        :param marker: the last item of the previous page; we return the next
+                       result set.
+        :param sort_key: Attribute by which results should be sorted.
+        :param sort_dir: direction in which results should be sorted.
+                         (asc, desc)
+        """
+
+    @abc.abstractmethod
+    def get_node_history_by_node_id(self, node_id, limit=None, marker=None,
+                                    sort_key=None, sort_dir=None):
+        """List all the history records for a given node.
+
+        :param node_id: The integer node ID.
+        :param limit: Maximum number of history records to return.
+        :param marker: the last item of the previous page; we return the next
+                       result set.
+        :param sort_key: Attribute by which results should be sorted
+        :param sort_dir: direction in which results should be sorted
+                         (asc, desc)
+        :returns: A list of histories.
+        """
+
+    @abc.abstractmethod
+    def query_node_history_records_for_purge(self, conductor_id):
+        """Utility method to identify nodes to clean history records for.
+
+        :param conductor_id: Id value for the conductor to perform this
+                             query on behalf of.
+        :returns: A dictionary with key values of node database ID values
+                  and a list of values associated with the node.
+        """
+
+    @abc.abstractmethod
+    def bulk_delete_node_history_records(self, node_id, limit):
+        """Utility method to bulk delete node history entries.
+
+        :param entires: A list of node history entriy id's to be
+                        queried for deletion.
+        """
