@@ -789,6 +789,11 @@ class Connection(api.Connection):
                 models.Allocation).filter_by(node_id=node_id)
             allocation_query.delete()
 
+            # delete all history for this node
+            history_query = model_query(
+                models.NodeHistory).filter_by(node_id=node_id)
+            history_query.delete()
+
             query.delete()
 
     def update_node(self, node_id, values):
@@ -1587,7 +1592,7 @@ class Connection(api.Connection):
                     model.version.notin_(versions)))
         return query.all()
 
-    def check_versions(self, ignore_models=()):
+    def check_versions(self, ignore_models=(), permit_initial_version=False):
         """Checks the whole database for incompatible objects.
 
         This scans all the tables in search of objects that are not supported;
@@ -1596,10 +1601,16 @@ class Connection(api.Connection):
         that have null 'version' values.
 
         :param ignore_models: List of model names to skip.
+        :param permit_initial_version: Boolean, default False, to permit a
+                                       NoSuchTableError exception to be raised
+                                       by SQLAlchemy and accordingly bypass
+                                       when an object has it's initial object
+                                       version.
         :returns: A Boolean. True if all the objects have supported versions;
                   False otherwise.
         """
         object_versions = release_mappings.get_object_versions()
+        table_missing_ok = False
         for model in models.Base.__subclasses__():
             if model.__name__ not in object_versions:
                 continue
@@ -1611,16 +1622,36 @@ class Connection(api.Connection):
             if not supported_versions:
                 continue
 
+            if permit_initial_version and supported_versions == {'1.0'}:
+                # We're getting called from someplace it is okay to handle
+                # a missing table, i.e. database upgrades which will create
+                # the table *and* the field version is 1.0, which means we
+                # are likely about to *create* the table, but first have to
+                # pass the version/compatability checking logic.
+                table_missing_ok = True
+
             # NOTE(mgagne): Additional safety check to detect old database
             # version which does not have the 'version' columns available.
             # This usually means a skip version upgrade is attempted
             # from a version earlier than Pike which added
             # those columns required for the next check.
-            engine = enginefacade.reader.get_engine()
-            if not db_utils.column_exists(engine,
-                                          model.__tablename__,
-                                          model.version.name):
-                raise exception.DatabaseVersionTooOld()
+            try:
+                engine = enginefacade.reader.get_engine()
+                if not db_utils.column_exists(engine,
+                                              model.__tablename__,
+                                              model.version.name):
+                    raise exception.DatabaseVersionTooOld()
+            except sa.exc.NoSuchTableError:
+                if table_missing_ok:
+                    # This is to be expected, it is okay. Moving along.
+                    LOG.warning('Observed missing table while performing '
+                                'upgrade version checking. This is not fatal '
+                                'as the expected version is only 1.0 and '
+                                'the check has been called before the table '
+                                'is to be created. Model: %s',
+                                model.__tablename__)
+                    continue
+                raise
 
             # NOTE(rloo): we use model.version, not model, because we
             #             know that the object has a 'version' column
@@ -2249,3 +2280,123 @@ class Connection(api.Connection):
         query = (_get_deploy_template_query_with_steps()
                  .filter(models.DeployTemplate.name.in_(names)))
         return query.all()
+
+    @oslo_db_api.retry_on_deadlock
+    def create_node_history(self, values):
+        values['uuid'] = uuidutils.generate_uuid()
+
+        history = models.NodeHistory()
+        history.update(values)
+        with _session_for_write() as session:
+            try:
+                session.add(history)
+                session.flush()
+            except db_exc.DBDuplicateEntry:
+                raise exception.NodeHistoryAlreadyExists(uuid=values['uuid'])
+            return history
+
+    @oslo_db_api.retry_on_deadlock
+    def destroy_node_history_by_uuid(self, history_uuid):
+        with _session_for_write():
+            query = model_query(models.NodeHistory).filter_by(
+                uuid=history_uuid)
+            count = query.delete()
+            if count == 0:
+                raise exception.NodeHistoryNotFound(history=history_uuid)
+
+    def get_node_history_by_id(self, history_id):
+        query = model_query(models.NodeHistory).filter_by(id=history_id)
+        try:
+            return query.one()
+        except NoResultFound:
+            raise exception.NodeHistoryNotFound(history=history_id)
+
+    def get_node_history_by_uuid(self, history_uuid):
+        query = model_query(models.NodeHistory).filter_by(uuid=history_uuid)
+        try:
+            return query.one()
+        except NoResultFound:
+            raise exception.NodeHistoryNotFound(history=history_uuid)
+
+    def get_node_history_list(self, limit=None, marker=None,
+                              sort_key='created_at', sort_dir='asc'):
+        return _paginate_query(models.NodeHistory, limit, marker, sort_key,
+                               sort_dir)
+
+    def get_node_history_by_node_id(self, node_id, limit=None, marker=None,
+                                    sort_key=None, sort_dir=None):
+        query = model_query(models.NodeHistory)
+        query = query.filter_by(node_id=node_id)
+        return _paginate_query(models.NodeHistory, limit, marker,
+                               sort_key, sort_dir, query)
+
+    def query_node_history_records_for_purge(self, conductor_id):
+        min_days = CONF.conductor.node_history_minimum_days
+        max_num = CONF.conductor.node_history_max_entries
+
+        with _session_for_read() as session:
+            # First, figure out our nodes.
+            nodes = session.query(
+                models.Node.id,
+            ).filter(
+                models.Node.conductor_affinity == conductor_id
+            )
+
+            # Build our query to get the node_id and record id.
+            query = session.query(
+                models.NodeHistory.node_id,
+                models.NodeHistory.id,
+            )
+
+            # Filter by the nodes
+            query = query.filter(
+                models.NodeHistory.node_id.in_(nodes)
+            ).order_by(
+                # Order in an ascending order as older is always first.
+                models.NodeHistory.created_at.asc()
+            )
+
+            # Filter by minimum days
+            if min_days > 0:
+                before = datetime.datetime.now() - datetime.timedelta(
+                    days=min_days)
+                query = query.filter(
+                    models.NodeHistory.created_at < before
+                )
+
+            # Build our result set
+            result_set = {}
+            for entry in query.all():
+                if entry[0] not in result_set:
+                    result_set[entry[0]] = []
+                result_set[entry[0]].append(entry[1])
+
+            final_set = {}
+            # Generate our final set of entries which should be removed
+            # by accounting for the number of permitted entries.
+            for entry in result_set:
+                final_set[entry] = []
+                set_len = len(result_set[entry])
+                # Any count <= the maximum number is okay
+                if set_len > max_num:
+                    # figure out how many entries need to be removed
+                    num_to_remove = set_len - max_num
+                    for i in range(0, num_to_remove):
+                        final_set[entry].append(result_set[entry][i])
+                        # remove the entries at the end of the list
+                        # which will be the more recent items as we
+                        # ordered ascending originally.
+            print('returning final set')
+            print(final_set)
+            return final_set
+
+    def bulk_delete_node_history_records(self, entries):
+        with _session_for_write() as session:
+            # Uses input entry list, selects entries matching those ids
+            # then deletes them and does not synchronize the session so
+            # sqlalchemy doesn't do extra un-necessary work.
+            session.query(
+                models.NodeHistory
+            ).filter(
+                models.NodeHistory.id.in_(entries)
+            ).delete(synchronize_session=False)
