@@ -513,16 +513,39 @@ def validate_capabilities(node):
                  'value': value, 'valid_values': ', '.join(valid_values)})
 
 
-def validate_image_properties(ctx, deploy_info, properties):
+def get_image_properties(ctx, image_href):
+    """Get properties of the image.
+
+    :param ctx: security context
+    :param image_href: reference to the image
+    :return: properties as a dictionary
+    :raises: InvalidParameterValue if the image cannot be accessed
+    """
+    try:
+        img_service = image_service.get_image_service(image_href, context=ctx)
+        return img_service.show(image_href)['properties']
+    except (exception.GlanceConnectionFailed,
+            exception.ImageNotAuthorized,
+            exception.Invalid):
+        raise exception.InvalidParameterValue(_(
+            "Failed to connect to Glance to get the properties "
+            "of the image %s") % image_href)
+    except exception.ImageNotFound:
+        raise exception.InvalidParameterValue(_(
+            "Image %s can not be found.") % image_href)
+    except exception.ImageRefValidationFailed as e:
+        raise exception.InvalidParameterValue(err=e)
+
+
+def validate_image_properties(task, deploy_info):
     """Validate the image.
 
     For Glance images it checks that the image exists in Glance and its
     properties or deployment info contain the properties passed. If it's not a
     Glance image, it checks that deployment info contains needed properties.
 
-    :param ctx: security context
+    :param task: TaskManager instance with a valid node
     :param deploy_info: the deploy_info to be validated
-    :param properties: the list of image meta-properties to be validated.
     :raises: InvalidParameterValue if:
         * connection to glance failed;
         * authorization for accessing image failed;
@@ -540,20 +563,25 @@ def validate_image_properties(ctx, deploy_info, properties):
             "specified at the same time."))
     if not image_href:
         image_href = boot_iso
-    try:
-        img_service = image_service.get_image_service(image_href, context=ctx)
-        image_props = img_service.show(image_href)['properties']
-    except (exception.GlanceConnectionFailed,
-            exception.ImageNotAuthorized,
-            exception.Invalid):
-        raise exception.InvalidParameterValue(_(
-            "Failed to connect to Glance to get the properties "
-            "of the image %s") % image_href)
-    except exception.ImageNotFound:
-        raise exception.InvalidParameterValue(_(
-            "Image %s can not be found.") % image_href)
-    except exception.ImageRefValidationFailed as e:
-        raise exception.InvalidParameterValue(err=e)
+
+    properties = []
+    if boot_iso or task.node.driver_internal_info.get('is_whole_disk_image'):
+        # No image properties are required in this case
+        return
+
+    if service_utils.is_glance_image(image_href):
+        properties = ['kernel_id', 'ramdisk_id']
+        boot_option = get_boot_option(task.node)
+        if boot_option == 'kickstart':
+            properties.append('squashfs_id')
+    else:
+        properties = ['kernel', 'ramdisk']
+
+    if image_href:
+        image_props = get_image_properties(task.context, image_href)
+    else:
+        # Ramdisk deploy, no image_source is present
+        image_props = []
 
     missing_props = []
     for prop in properties:
@@ -761,17 +789,28 @@ def get_image_instance_info(node):
     # more explicit unit testing to exist.
     info = {}
 
-    is_whole_disk_image = node.driver_internal_info.get('is_whole_disk_image')
     boot_iso = node.instance_info.get('boot_iso')
-    if not boot_iso:
-        info['image_source'] = node.instance_info.get('image_source')
-    else:
+    image_source = node.instance_info.get('image_source')
+    if boot_iso:
+        if image_source:
+            raise exception.InvalidParameterValue(_(
+                "An 'image_source' and 'boot_iso' parameter may not be "
+                "specified at the same time."))
         info['boot_iso'] = boot_iso
-
-    if not is_whole_disk_image and not boot_iso:
-        if not service_utils.is_glance_image(info['image_source']):
+    else:
+        if get_boot_option(node) == 'ramdisk':
+            # Ramdisk deploy does not require an image
             info['kernel'] = node.instance_info.get('kernel')
             info['ramdisk'] = node.instance_info.get('ramdisk')
+        else:
+            info['image_source'] = image_source
+
+            is_whole_disk_image = node.driver_internal_info.get(
+                'is_whole_disk_image')
+            if (not is_whole_disk_image
+                    and not service_utils.is_glance_image(image_source)):
+                info['kernel'] = node.instance_info.get('kernel')
+                info['ramdisk'] = node.instance_info.get('ramdisk')
 
     error_msg = (_("Cannot validate image information for node %s because one "
                    "or more parameters are missing from its instance_info and "
