@@ -25,6 +25,8 @@ import time
 
 from futurist import periodics
 from ironic_lib import metrics_utils
+import jsonschema
+from jsonschema import exceptions as json_schema_exc
 from oslo_log import log as logging
 from oslo_utils import importutils
 
@@ -93,6 +95,23 @@ _CLEAR_JOB_IDS = 'JID_CLEARALL'
 # Clean steps constant
 _CLEAR_JOBS_CLEAN_STEPS = ['clear_job_queue', 'known_good_state']
 
+_CONF_MOLD_SCHEMA = {
+    'type': 'object',
+    'properties': {
+        'oem': {
+            'type': 'object',
+            'properties': {
+                'interface': {'const': 'idrac-redfish'},
+                'data': {'type': 'object', 'minProperties': 1}
+            },
+            'required': ['interface', 'data']
+        }
+
+    },
+    'required': ['oem'],
+    'additionalProperties': False
+}
+
 
 def _get_boot_device(node, drac_boot_devices=None):
     client = drac_common.get_drac_client(node)
@@ -186,6 +205,19 @@ def _flexibly_program_boot_order(device, drac_boot_mode):
     return bios_settings
 
 
+def _validate_conf_mold(data):
+    """Validates iDRAC configuration mold JSON schema
+
+    :param data: dictionary of configuration mold data
+    :raises InvalidParameterValue: If configuration mold validation fails
+    """
+    try:
+        jsonschema.validate(data, _CONF_MOLD_SCHEMA)
+    except json_schema_exc.ValidationError as e:
+        raise exception.InvalidParameterValue(
+            _("Invalid configuration mold: %(error)s") % {'error': e})
+
+
 def set_boot_device(node, device, persistent=False):
     """Set the boot device for a node.
 
@@ -407,15 +439,7 @@ class DracRedfishManagement(redfish_management.RedfishManagement):
                        {'node': task.node.uuid,
                         'configuration_name': import_configuration_location}))
 
-        interface = configuration["oem"]["interface"]
-        if interface != "idrac-redfish":
-            raise exception.DracOperationError(
-                error=(_("Invalid configuration for node %(node)s "
-                         "in %(configuration_name)s. Supports only "
-                         "idrac-redfish, but found %(interface)s") %
-                       {'node': task.node.uuid,
-                        'configuration_name': import_configuration_location,
-                        'interface': interface}))
+        _validate_conf_mold(configuration)
 
         task_monitor = drac_utils.execute_oem_manager_method(
             task, 'import system configuration',
@@ -478,6 +502,17 @@ class DracRedfishManagement(redfish_management.RedfishManagement):
         for (node_uuid, driver, conductor_group,
              driver_internal_info) in node_list:
             try:
+
+                task_monitor_url = driver_internal_info.get(
+                    'import_task_monitor_url')
+                # NOTE(TheJulia): Evaluate if a task montitor URL exists
+                # based upon our inital DB query before pulling a task for
+                # every node in the deployment which reduces the overall
+                # number of DB queries triggering in the background where
+                # no work is required.
+                if not task_monitor_url:
+                    continue
+
                 lock_purpose = 'checking async import configuration task'
                 with task_manager.acquire(context, node_uuid,
                                           purpose=lock_purpose,
@@ -485,10 +520,6 @@ class DracRedfishManagement(redfish_management.RedfishManagement):
                     if not isinstance(task.driver.management,
                                       DracRedfishManagement):
                         continue
-                    task_monitor_url = driver_internal_info.get(
-                        'import_task_monitor_url')
-                    if not task_monitor_url:
-                        continue
                     self._check_import_configuration_task(
                         task, task_monitor_url)
             except exception.NodeNotFound:
@@ -504,7 +535,29 @@ class DracRedfishManagement(redfish_management.RedfishManagement):
         """Checks progress of running import configuration task"""
 
         node = task.node
-        task_monitor = redfish_utils.get_task_monitor(node, task_monitor_url)
+        try:
+            task_monitor = redfish_utils.get_task_monitor(
+                node, task_monitor_url)
+        except exception.RedfishError as e:
+            error_msg = (_("Failed import configuration task: "
+                           "%(task_monitor_url)s. Message: '%(message)s'. "
+                           "Most likely this happened because could not find "
+                           "the task anymore as it got deleted by iDRAC. "
+                           "If not already, upgrade iDRAC firmware to "
+                           "5.00.00.00 or later that preserves tasks for "
+                           "longer or decrease "
+                           "[drac]query_import_config_job_status_interval")
+                         % {'task_monitor_url': task_monitor_url,
+                            'message': e})
+            log_msg = ("Import configuration task failed for node "
+                       "%(node)s. %(error)s" % {'node': task.node.uuid,
+                                                'error': error_msg})
+            info = node.driver_internal_info
+            info.pop('import_task_monitor_url', None)
+            node.driver_internal_info = info
+            node.save()
+            self._set_failed(task, log_msg, error_msg)
+            return
 
         if not task_monitor.is_processing:
             import_task = task_monitor.get_task()
@@ -514,9 +567,21 @@ class DracRedfishManagement(redfish_management.RedfishManagement):
             info.pop('import_task_monitor_url', None)
             node.driver_internal_info = info
 
+            succeeded = False
             if (import_task.task_state == sushy.TASK_STATE_COMPLETED
                 and import_task.task_status in
                     [sushy.HEALTH_OK, sushy.HEALTH_WARNING]):
+
+                # Task could complete with errors (partial success)
+                # iDRAC 5.00.00.00 has stopped reporting Critical messages
+                # so checking also by message_id
+                succeeded = not any(m.message for m in import_task.messages
+                                    if (m.severity
+                                        and m.severity != sushy.SEVERITY_OK)
+                                    or (m.message_id and 'SYS055'
+                                        in m.message_id))
+
+            if succeeded:
                 LOG.info('Configuration import %(task_monitor_url)s '
                          'successful for node %(node)s',
                          {'node': node.uuid,
@@ -546,7 +611,11 @@ class DracRedfishManagement(redfish_management.RedfishManagement):
                 # Select all messages, skipping OEM messages that don't have
                 # `message` field populated.
                 messages = [m.message for m in import_task.messages
-                            if m.message is not None]
+                            if m.message is not None
+                            and ((m.severity
+                                  and m.severity != sushy.SEVERITY_OK)
+                                 or (m.message_id
+                                     and 'SYS055' in m.message_id))]
                 error_msg = (_("Failed import configuration task: "
                                "%(task_monitor_url)s. Message: '%(message)s'.")
                              % {'task_monitor_url': task_monitor_url,
