@@ -19,7 +19,6 @@ from futurist import periodics
 from ironic_lib import metrics_utils
 from oslo_log import log as logging
 from oslo_utils import importutils
-import six
 
 from ironic.common import exception
 from ironic.common import raid as raid_common
@@ -392,7 +391,7 @@ class IRMCRAID(base.RAIDInterface):
         logical_disks = target_raid_config['logical_disks']
         for log_disk in logical_disks:
             if log_disk.get('raid_level'):
-                log_disk['raid_level'] = six.text_type(
+                log_disk['raid_level'] = str(
                     log_disk['raid_level']).replace('+', '')
 
         # Validate physical disks on Fujitsu BM Server
@@ -435,6 +434,13 @@ class IRMCRAID(base.RAIDInterface):
         node_list = manager.iter_nodes(fields=fields, filters=filters)
         for (node_uuid, driver, conductor_group, raid_config) in node_list:
             try:
+                # NOTE(TheJulia): Evaluate based upon presence of raid
+                # configuration before triggering a task, as opposed to after
+                # so we don't create excess node task objects with related
+                # DB queries.
+                if not raid_config or raid_config.get('fgi_status'):
+                    continue
+
                 lock_purpose = 'checking async RAID configuration tasks'
                 with task_manager.acquire(context, node_uuid,
                                           purpose=lock_purpose,
@@ -445,8 +451,6 @@ class IRMCRAID(base.RAIDInterface):
                         continue
                     if task.node.target_raid_config is None:
                         continue
-                    if not raid_config or raid_config.get('fgi_status'):
-                        continue
                     task.upgrade_lock()
                     if node.provision_state != states.CLEANWAIT:
                         continue
