@@ -19,6 +19,7 @@ from oslo_utils import importutils
 from ironic.common import exception
 from ironic.common.i18n import _
 from ironic.common import states
+from ironic.conductor import task_manager
 from ironic.conductor import utils as manager_utils
 from ironic.drivers import base
 from ironic.drivers.modules import deploy_utils
@@ -31,6 +32,10 @@ METRICS = metrics_utils.get_metrics_logger(__name__)
 
 sushy = importutils.try_import('sushy')
 
+registry_fields = ('attribute_type', 'allowable_values', 'lower_bound',
+                   'max_length', 'min_length', 'read_only',
+                   'reset_required', 'unique', 'upper_bound')
+
 
 class RedfishBIOS(base.BIOSInterface):
 
@@ -50,6 +55,23 @@ class RedfishBIOS(base.BIOSInterface):
                 driver='redfish',
                 reason=_("Unable to import the sushy library"))
 
+    def _parse_allowable_values(self, allowable_values):
+        """Convert the BIOS registry allowable_value list to expected strings
+
+        :param allowable_values: list of dicts of valid values for enumeration
+        :returns: list containing only allowable value names
+        """
+
+        # Get name from ValueName if it exists, otherwise use DisplayValueName
+        new_list = []
+        for dic in allowable_values:
+            for key in dic:
+                if key == 'ValueName' or key == 'DisplayValueName':
+                    new_list.append(dic[key])
+                    break
+
+        return new_list
+
     def cache_bios_settings(self, task):
         """Store or update the current BIOS settings for the node.
 
@@ -76,7 +98,39 @@ class RedfishBIOS(base.BIOSInterface):
         settings = []
         # Convert Redfish BIOS attributes to Ironic BIOS settings
         if attributes:
-            settings = [{'name': k, 'value': v} for k, v in attributes.items()]
+            settings = [{'name': k, 'value': v}
+                        for k, v in attributes.items()]
+
+        # Get the BIOS Registry
+        registry_attributes = []
+        try:
+            bios_registry = system.bios.get_attribute_registry()
+
+            if bios_registry:
+                registry_attributes = bios_registry.registry_entries.attributes
+
+        except Exception as e:
+            LOG.info('Cannot get BIOS Registry attributes for node %(node)s, '
+                     'Error %(exc)s.', {'node': task.node.uuid, 'exc': e})
+
+        # TODO(bfournier): use a common list for registry field names
+        # e.g. registry_fields = objects.BIOSSetting.registry_fields
+
+        # The BIOS registry will contain more entries than the BIOS settings
+        # Find the registry entry matching the setting name and get the fields
+        if registry_attributes:
+            for setting in settings:
+                reg = next((r for r in registry_attributes
+                            if r.name == setting['name']), None)
+                fields = [attr for attr in dir(reg)
+                          if not attr.startswith("_")]
+                settable_keys = [f for f in fields if f in registry_fields]
+                # Set registry fields to current values
+                for k in settable_keys:
+                    setting[k] = getattr(reg, k, None)
+                    if k == "allowable_values" and isinstance(setting[k],
+                                                              list):
+                        setting[k] = self._parse_allowable_values(setting[k])
 
         LOG.debug('Cache BIOS settings for node %(node_uuid)s',
                   {'node_uuid': task.node.uuid})
@@ -131,8 +185,9 @@ class RedfishBIOS(base.BIOSInterface):
                 LOG.error(error_msg)
                 raise exception.RedfishError(error=error_msg)
 
+            self.post_reset(task)
             self._set_reboot(task)
-            return self.post_reset(task)
+            return deploy_utils.get_async_step_return_state(task.node)
         else:
             current_attrs = bios.attributes
             LOG.debug('Post factory reset, BIOS configuration for node '
@@ -189,8 +244,9 @@ class RedfishBIOS(base.BIOSInterface):
                 LOG.error(error_msg)
                 raise exception.RedfishError(error=error_msg)
 
+            self.post_configuration(task, settings)
             self._set_reboot_requested(task, attributes)
-            return self.post_configuration(task, settings)
+            return deploy_utils.get_async_step_return_state(task.node)
         else:
             # Step 2: Verify requested BIOS settings applied
             requested_attrs = info.get('requested_bios_attrs')
@@ -211,7 +267,9 @@ class RedfishBIOS(base.BIOSInterface):
 
         :param task: a TaskManager instance containing the node to act on.
         """
-        return deploy_utils.reboot_to_finish_step(task)
+        deploy_opts = deploy_utils.build_agent_options(task.node)
+        task.driver.boot.prepare_ramdisk(task, deploy_opts)
+        self._reboot(task)
 
     def post_configuration(self, task, settings):
         """Perform post configuration action to store the BIOS settings.
@@ -224,7 +282,9 @@ class RedfishBIOS(base.BIOSInterface):
         :param task: a TaskManager instance containing the node to act on.
         :param settings: a list of BIOS settings to be updated.
         """
-        return deploy_utils.reboot_to_finish_step(task)
+        deploy_opts = deploy_utils.build_agent_options(task.node)
+        task.driver.boot.prepare_ramdisk(task, deploy_opts)
+        self._reboot(task)
 
     def get_properties(self):
         """Return the properties of the interface.
@@ -264,6 +324,17 @@ class RedfishBIOS(base.BIOSInterface):
             LOG.debug('Verification of BIOS settings for node %(node_uuid)s '
                       'successful.', {'node_uuid': task.node.uuid})
 
+    @task_manager.require_exclusive_lock
+    def _reboot(self, task):
+        """Reboot the target Redfish service.
+
+        :param task: a TaskManager instance containing the node to act on.
+        :raises: InvalidParameterValue when the wrong state is specified
+             or the wrong driver info is specified.
+        :raises: RedfishError on an error from the Sushy library
+        """
+        manager_utils.node_power_action(task, states.REBOOT)
+
     def _set_reboot(self, task):
         """Set driver_internal_info flags for deployment or cleaning reboot.
 
