@@ -384,3 +384,71 @@ OPTIONAL_PROPERTIES = {
                                       "deprecated in favor of the new ones."
                                       "Defaults to 'Default'. Optional."),
 }
+
+
+def get_kernel_append_params(node, default):
+    """Get the applicable kernel params.
+
+    The locations are checked in this order:
+
+    1. The node's instance_info.
+    2. The node's driver_info.
+    3. Configuration.
+
+    :param node: Node object.
+    :param default: Default value.
+    """
+    for location in ('instance_info', 'driver_info'):
+        result = getattr(node, location).get('kernel_append_params')
+        if result is not None:
+            return result
+
+    return default
+
+
+def get_field(node, name, deprecated_prefix=None, use_conf=False,
+              collection='driver_info'):
+    """Get a driver_info field with deprecated prefix."""
+    node_coll = getattr(node, collection)
+    value = node_coll.get(name)
+    if value or not deprecated_prefix:
+        return value
+
+    deprecated_name = f'{deprecated_prefix}_{name}'
+    value = node_coll.get(deprecated_name)
+    if value:
+        LOG.warning("The %s field %s of node %s is deprecated, "
+                    "please use %s instead",
+                    collection, deprecated_name, node.uuid, name)
+        return value
+
+    if use_conf:
+        return getattr(CONF.conductor, name)
+
+
+def get_agent_kernel_ramdisk(node, mode='deploy', deprecated_prefix=None):
+    """Get the agent kernel/ramdisk as a dictionary."""
+    kernel_name = f'{mode}_kernel'
+    ramdisk_name = f'{mode}_ramdisk'
+    kernel, ramdisk = (
+        get_field(node, kernel_name, deprecated_prefix),
+        get_field(node, ramdisk_name, deprecated_prefix),
+    )
+    # NOTE(dtantsur): avoid situation when e.g. deploy_kernel comes
+    # from driver_info but deploy_ramdisk comes from configuration,
+    # since it's a sign of a potential operator's mistake.
+    if not kernel or not ramdisk:
+        return {
+            kernel_name: getattr(CONF.conductor, kernel_name),
+            ramdisk_name: getattr(CONF.conductor, ramdisk_name),
+        }
+    else:
+        return {
+            kernel_name: kernel,
+            ramdisk_name: ramdisk
+        }
+
+
+def get_agent_iso(node, mode='deploy', deprecated_prefix=None):
+    """Get the agent ISO image."""
+    return get_field(node, f'{mode}_iso', deprecated_prefix)
