@@ -16,7 +16,7 @@
 
 """Base classes for our unit tests.
 
-Allows overriding of config for use of fakes, and some black magic for
+Allows overriding of config for use of fakes, and some magic for
 inline callbacks.
 
 """
@@ -26,6 +26,7 @@ import os
 import subprocess
 import sys
 import tempfile
+from unittest import mock
 
 import eventlet
 eventlet.monkey_patch(os=False)
@@ -53,6 +54,21 @@ logging.register_options(CONF)
 logging.setup(CONF, 'ironic')
 
 
+# NOTE(rpittau) this function allows autospec for classmethods and
+# staticmethods in Python 3.6, while no issue occurs in Python 3.7.4
+# and later.
+# For more info please see: http://bugs.python.org/issue23078
+def _patch_mock_callable(obj):
+    if isinstance(obj, type):
+        return True
+    if getattr(obj, '__call__', None) is not None:
+        return True
+    if (isinstance(obj, (staticmethod, classmethod))
+            and mock._callable(obj.__func__)):
+        return True
+    return False
+
+
 class ReplaceModule(fixtures.Fixture):
     """Replace a module with a fake module."""
 
@@ -117,10 +133,13 @@ class TestCase(oslo_test_base.BaseTestCase):
             # subprocess.Popen is a class
             self.patch(subprocess, 'Popen', DoNotCallPopen)
 
+        if sys.version_info < (3, 7, 4):
+            _patch_mock_callable._old_func = mock._callable
+            mock._callable = _patch_mock_callable
+
     def _set_config(self):
         self.cfg_fixture = self.useFixture(config_fixture.Config(CONF))
         self.config(use_stderr=False,
-                    fatal_exception_format_errors=True,
                     tempdir=tempfile.tempdir)
         self.config(cleaning_network=uuidutils.generate_uuid(),
                     group='neutron')
@@ -140,7 +159,7 @@ class TestCase(oslo_test_base.BaseTestCase):
                 values = ['fake']
 
             if iface == 'deploy':
-                values.extend(['iscsi', 'direct'])
+                values.extend(['direct', 'anaconda'])
             elif iface == 'boot':
                 values.append('pxe')
             elif iface == 'storage':
