@@ -29,7 +29,6 @@ from ironic.api.controllers.v1 import notification_utils
 from ironic.api.controllers.v1 import utils as api_utils
 from ironic.common import exception
 from ironic.common import states
-from ironic.common import utils as common_utils
 from ironic.conductor import rpcapi
 from ironic import objects
 from ironic.objects import fields as obj_fields
@@ -538,7 +537,7 @@ class TestListPortgroups(test_api_base.BaseApiTest):
     def test_detail_sort_key_not_allowed(self):
         self._test_sort_key_not_allowed(detail=True)
 
-    @mock.patch.object(api_utils, 'get_rpc_node')
+    @mock.patch.object(api_utils, 'get_rpc_node', autospec=True)
     def test_get_all_by_node_name_ok(self, mock_get_rpc_node):
         # GET /v1/portgroups specifying node_name - success
         mock_get_rpc_node.return_value = self.node
@@ -557,7 +556,7 @@ class TestListPortgroups(test_api_base.BaseApiTest):
                              headers=self.headers)
         self.assertEqual(3, len(data['portgroups']))
 
-    @mock.patch.object(api_utils, 'get_rpc_node')
+    @mock.patch.object(api_utils, 'get_rpc_node', autospec=True)
     def test_get_all_by_node_uuid_ok(self, mock_get_rpc_node):
         mock_get_rpc_node.return_value = self.node
         obj_utils.create_test_portgroup(self.context, node_id=self.node.id)
@@ -566,7 +565,7 @@ class TestListPortgroups(test_api_base.BaseApiTest):
         mock_get_rpc_node.assert_called_once_with(self.node.uuid)
         self.assertEqual(1, len(data['portgroups']))
 
-    @mock.patch.object(api_utils, 'get_rpc_node')
+    @mock.patch.object(api_utils, 'get_rpc_node', autospec=True)
     def test_detail_by_node_name_ok(self, mock_get_rpc_node):
         # GET /v1/portgroups/detail specifying node_name - success
         mock_get_rpc_node.return_value = self.node
@@ -578,7 +577,7 @@ class TestListPortgroups(test_api_base.BaseApiTest):
         self.assertEqual(self.node.uuid, data['portgroups'][0]['node_uuid'])
 
 
-@mock.patch.object(rpcapi.ConductorAPI, 'update_portgroup')
+@mock.patch.object(rpcapi.ConductorAPI, 'update_portgroup', autospec=True)
 class TestPatch(test_api_base.BaseApiTest):
     headers = {api_base.Version.string: str(api_v1.max_version())}
 
@@ -589,12 +588,14 @@ class TestPatch(test_api_base.BaseApiTest):
                                                          name='pg.1',
                                                          node_id=self.node.id)
 
-        p = mock.patch.object(rpcapi.ConductorAPI, 'get_topic_for')
+        p = mock.patch.object(rpcapi.ConductorAPI, 'get_topic_for',
+                              autospec=True)
         self.mock_gtf = p.start()
         self.mock_gtf.return_value = 'test-topic'
         self.addCleanup(p.stop)
 
-    @mock.patch.object(notification_utils, '_emit_api_notification')
+    @mock.patch.object(notification_utils, '_emit_api_notification',
+                       autospec=True)
     def test_update_byid(self, mock_notify, mock_upd):
         extra = {'foo': 'bar'}
         mock_upd.return_value = self.portgroup
@@ -608,7 +609,7 @@ class TestPatch(test_api_base.BaseApiTest):
         self.assertEqual(http_client.OK, response.status_code)
         self.assertEqual(extra, response.json['extra'])
 
-        kargs = mock_upd.call_args[0][1]
+        kargs = mock_upd.call_args[0][2]
         self.assertEqual(extra, kargs.extra)
         mock_notify.assert_has_calls([mock.call(mock.ANY, mock.ANY, 'update',
                                       obj_fields.NotificationLevel.INFO,
@@ -710,10 +711,11 @@ class TestPatch(test_api_base.BaseApiTest):
         self.assertEqual(address, response.json['address'])
         self.assertTrue(mock_upd.called)
 
-        kargs = mock_upd.call_args[0][1]
+        kargs = mock_upd.call_args[0][2]
         self.assertEqual(address, kargs.address)
 
-    @mock.patch.object(notification_utils, '_emit_api_notification')
+    @mock.patch.object(notification_utils, '_emit_api_notification',
+                       autospec=True)
     def test_replace_address_already_exist(self, mock_notify, mock_upd):
         address = 'aa:aa:aa:aa:aa:aa'
         mock_upd.side_effect = exception.MACAlreadyExists(mac=address)
@@ -728,7 +730,7 @@ class TestPatch(test_api_base.BaseApiTest):
         self.assertTrue(response.json['error_message'])
         self.assertTrue(mock_upd.called)
 
-        kargs = mock_upd.call_args[0][1]
+        kargs = mock_upd.call_args[0][2]
         self.assertEqual(address, kargs.address)
         mock_notify.assert_has_calls([mock.call(mock.ANY, mock.ANY, 'update',
                                       obj_fields.NotificationLevel.INFO,
@@ -824,7 +826,7 @@ class TestPatch(test_api_base.BaseApiTest):
         self.assertEqual('application/json', response.content_type)
         self.assertEqual(http_client.OK, response.status_code)
         self.assertEqual(extra, response.json['extra'])
-        kargs = mock_upd.call_args[0][1]
+        kargs = mock_upd.call_args[0][2]
         self.assertEqual(extra, kargs.extra)
 
     def test_remove_multi(self, mock_upd):
@@ -843,7 +845,7 @@ class TestPatch(test_api_base.BaseApiTest):
         self.assertEqual('application/json', response.content_type)
         self.assertEqual(http_client.OK, response.status_code)
         self.assertEqual(extra, response.json['extra'])
-        kargs = mock_upd.call_args[0][1]
+        kargs = mock_upd.call_args[0][2]
         self.assertEqual(extra, kargs.extra)
 
         # Removing the collection
@@ -855,7 +857,7 @@ class TestPatch(test_api_base.BaseApiTest):
         self.assertEqual('application/json', response.content_type)
         self.assertEqual(http_client.OK, response.status_code)
         self.assertEqual({}, response.json['extra'])
-        kargs = mock_upd.call_args[0][1]
+        kargs = mock_upd.call_args[0][2]
         self.assertEqual(extra, kargs.extra)
 
         # Assert nothing else was changed
@@ -898,7 +900,7 @@ class TestPatch(test_api_base.BaseApiTest):
         self.assertEqual(http_client.OK, response.status_code)
         self.assertEqual(address, response.json['address'])
         self.assertTrue(mock_upd.called)
-        kargs = mock_upd.call_args[0][1]
+        kargs = mock_upd.call_args[0][2]
         self.assertEqual(address, kargs.address)
 
     def test_add_root_non_existent(self, mock_upd):
@@ -927,7 +929,7 @@ class TestPatch(test_api_base.BaseApiTest):
         self.assertEqual('application/json', response.content_type)
         self.assertEqual(http_client.OK, response.status_code)
         self.assertEqual(extra, response.json['extra'])
-        kargs = mock_upd.call_args[0][1]
+        kargs = mock_upd.call_args[0][2]
         self.assertEqual(extra, kargs.extra)
 
     def test_remove_uuid(self, mock_upd):
@@ -965,7 +967,7 @@ class TestPatch(test_api_base.BaseApiTest):
         self.assertEqual('application/json', response.content_type)
         self.assertEqual(http_client.OK, response.status_code)
         self.assertEqual(address.lower(), response.json['address'])
-        kargs = mock_upd.call_args[0][1]
+        kargs = mock_upd.call_args[0][2]
         self.assertEqual(address.lower(), kargs.address)
 
     def test_update_portgroup_standalone_ports_supported(self, mock_upd):
@@ -1080,140 +1082,10 @@ class TestPatch(test_api_base.BaseApiTest):
         self.assertEqual(http_client.OK, response.status_int)
         self.assertEqual(address.lower(), response.json['address'])
         self.assertTrue(mock_upd.called)
-        kargs = mock_upd.call_args[0][1]
+        kargs = mock_upd.call_args[0][2]
         self.assertEqual(address.lower(), kargs.address)
 
 
-@mock.patch.object(rpcapi.ConductorAPI, 'update_portgroup', autospec=True,
-                   side_effect=_rpcapi_update_portgroup)
-class TestPatchExtraVifPortId(test_api_base.BaseApiTest):
-    headers = {api_base.Version.string: str(api_v1.max_version())}
-
-    def setUp(self):
-        super(TestPatchExtraVifPortId, self).setUp()
-        self.node = obj_utils.create_test_node(self.context)
-        self.portgroup = obj_utils.create_test_portgroup(self.context,
-                                                         node_id=self.node.id)
-        p = mock.patch.object(rpcapi.ConductorAPI, 'get_topic_for')
-        self.mock_gtf = p.start()
-        self.mock_gtf.return_value = 'test-topic'
-        self.addCleanup(p.stop)
-
-    def _test_add_extra_vif_port_id(self, headers, mock_warn, mock_upd):
-        extra = {'vif_port_id': 'bar'}
-        response = self.patch_json(
-            '/portgroups/%s' % self.portgroup.uuid,
-            [{'path': '/extra/vif_port_id', 'value': 'foo', 'op': 'add'},
-             {'path': '/extra/vif_port_id', 'value': 'bar', 'op': 'add'}],
-            headers=headers)
-        self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.OK, response.status_code)
-        self.assertEqual(extra, response.json['extra'])
-        return response
-
-    @mock.patch.object(common_utils, 'warn_about_deprecated_extra_vif_port_id',
-                       autospec=True)
-    def test_add_extra_vif_port_id(self, mock_warn, mock_upd):
-        expected_intern_info = self.portgroup.internal_info
-        expected_intern_info.update({'tenant_vif_port_id': 'bar'})
-        headers = {api_base.Version.string: '1.27'}
-        response = self._test_add_extra_vif_port_id(headers, mock_warn,
-                                                    mock_upd)
-        self.assertEqual(expected_intern_info, response.json['internal_info'])
-        self.assertFalse(mock_warn.called)
-
-    @mock.patch.object(common_utils, 'warn_about_deprecated_extra_vif_port_id',
-                       autospec=True)
-    def test_add_extra_vif_port_id_deprecated(self, mock_warn, mock_upd):
-        expected_intern_info = self.portgroup.internal_info
-        expected_intern_info.update({'tenant_vif_port_id': 'bar'})
-        response = self._test_add_extra_vif_port_id(self.headers, mock_warn,
-                                                    mock_upd)
-        self.assertEqual(expected_intern_info, response.json['internal_info'])
-        self.assertTrue(mock_warn.called)
-
-    @mock.patch.object(common_utils, 'warn_about_deprecated_extra_vif_port_id',
-                       autospec=True)
-    def test_replace_extra_vif_port_id(self, mock_warn, mock_upd):
-        self.portgroup.extra = {'vif_port_id': 'original'}
-        self.portgroup.internal_info = {'tenant_vif_port_id': 'original'}
-        self.portgroup.save()
-        expected_intern_info = self.portgroup.internal_info
-        expected_intern_info.update({'tenant_vif_port_id': 'bar'})
-        headers = {api_base.Version.string: '1.27'}
-        response = self._test_add_extra_vif_port_id(headers, mock_warn,
-                                                    mock_upd)
-        self.assertEqual(expected_intern_info, response.json['internal_info'])
-        self.assertFalse(mock_warn.called)
-
-    @mock.patch.object(common_utils, 'warn_about_deprecated_extra_vif_port_id',
-                       autospec=True)
-    def test_add_extra_vif_port_id_diff_internal(self, mock_warn, mock_upd):
-        internal_info = {'tenant_vif_port_id': 'original'}
-        self.portgroup.internal_info = internal_info
-        self.portgroup.save()
-        headers = {api_base.Version.string: '1.27'}
-        response = self._test_add_extra_vif_port_id(headers, mock_warn,
-                                                    mock_upd)
-        # not changed
-        self.assertEqual(internal_info, response.json['internal_info'])
-        self.assertFalse(mock_warn.called)
-
-    def _test_remove_extra_vif_port_id(self, headers, mock_warn, mock_upd):
-        response = self.patch_json(
-            '/portgroups/%s' % self.portgroup.uuid,
-            [{'path': '/extra/vif_port_id', 'op': 'remove'}],
-            headers=headers)
-        self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.OK, response.status_code)
-        self.assertEqual({}, response.json['extra'])
-        self.assertTrue(mock_upd.called)
-        return response
-
-    @mock.patch.object(common_utils, 'warn_about_deprecated_extra_vif_port_id',
-                       autospec=True)
-    def test_remove_extra_vif_port_id(self, mock_warn, mock_upd):
-        self.portgroup.extra = {'vif_port_id': 'bar'}
-        orig_info = self.portgroup.internal_info.copy()
-        intern_info = self.portgroup.internal_info
-        intern_info.update({'tenant_vif_port_id': 'bar'})
-        self.portgroup.internal_info = intern_info
-        self.portgroup.save()
-        headers = {api_base.Version.string: '1.27'}
-        response = self._test_remove_extra_vif_port_id(headers, mock_warn,
-                                                       mock_upd)
-        self.assertEqual(orig_info, response.json['internal_info'])
-        self.assertFalse(mock_warn.called)
-
-    @mock.patch.object(common_utils, 'warn_about_deprecated_extra_vif_port_id',
-                       autospec=True)
-    def test_remove_extra_vif_port_id_not_same(self, mock_warn, mock_upd):
-        # .internal_info['tenant_vif_port_id'] != .extra['vif_port_id']
-        self.portgroup.extra = {'vif_port_id': 'foo'}
-        intern_info = self.portgroup.internal_info
-        intern_info.update({'tenant_vif_port_id': 'bar'})
-        self.portgroup.internal_info = intern_info
-        self.portgroup.save()
-        headers = {api_base.Version.string: '1.28'}
-        response = self._test_remove_extra_vif_port_id(headers, mock_warn,
-                                                       mock_upd)
-        self.assertEqual(intern_info, response.json['internal_info'])
-        self.assertTrue(mock_warn.called)
-
-    @mock.patch.object(common_utils, 'warn_about_deprecated_extra_vif_port_id',
-                       autospec=True)
-    def test_remove_extra_vif_port_id_not_internal(self, mock_warn, mock_upd):
-        # no portgroup.internal_info['tenant_vif_port_id']
-        self.portgroup.extra = {'vif_port_id': 'foo'}
-        self.portgroup.save()
-        intern_info = self.portgroup.internal_info
-        headers = {api_base.Version.string: '1.28'}
-        response = self._test_remove_extra_vif_port_id(headers, mock_warn,
-                                                       mock_upd)
-        self.assertEqual(intern_info, response.json['internal_info'])
-        self.assertTrue(mock_warn.called)
-
-
 class TestPost(test_api_base.BaseApiTest):
     headers = {api_base.Version.string: str(api_v1.max_version())}
 
@@ -1221,11 +1093,10 @@ class TestPost(test_api_base.BaseApiTest):
         super(TestPost, self).setUp()
         self.node = obj_utils.create_test_node(self.context)
 
-    @mock.patch.object(notification_utils, '_emit_api_notification')
-    @mock.patch.object(common_utils, 'warn_about_deprecated_extra_vif_port_id',
+    @mock.patch.object(notification_utils, '_emit_api_notification',
                        autospec=True)
     @mock.patch.object(timeutils, 'utcnow', autospec=True)
-    def test_create_portgroup(self, mock_utcnow, mock_warn, mock_notify):
+    def test_create_portgroup(self, mock_utcnow, mock_notify):
         pdict = apiutils.post_get_test_portgroup()
         test_time = datetime.datetime(2000, 1, 1, 0, 0)
         mock_utcnow.return_value = test_time
@@ -1244,7 +1115,6 @@ class TestPost(test_api_base.BaseApiTest):
         expected_location = '/v1/portgroups/%s' % pdict['uuid']
         self.assertEqual(urlparse.urlparse(response.location).path,
                          expected_location)
-        self.assertEqual(0, mock_warn.call_count)
         mock_notify.assert_has_calls([mock.call(mock.ANY, mock.ANY, 'create',
                                       obj_fields.NotificationLevel.INFO,
                                       obj_fields.NotificationStatus.START,
@@ -1309,8 +1179,9 @@ class TestPost(test_api_base.BaseApiTest):
         self.assertFalse(mock_warn.called)
         self.assertFalse(mock_except.called)
 
-    @mock.patch.object(notification_utils, '_emit_api_notification')
-    @mock.patch.object(objects.Portgroup, 'create')
+    @mock.patch.object(notification_utils, '_emit_api_notification',
+                       autospec=True)
+    @mock.patch.object(objects.Portgroup, 'create', autospec=True)
     def test_create_portgroup_error(self, mock_create, mock_notify):
         mock_create.side_effect = Exception()
         pdict = apiutils.post_get_test_portgroup()
@@ -1334,41 +1205,6 @@ class TestPost(test_api_base.BaseApiTest):
                                headers=self.headers)
         self.assertEqual(pdict['extra'], result['extra'])
 
-    def _test_create_portgroup_with_extra_vif_port_id(self, headers,
-                                                      mock_warn):
-        pgdict = apiutils.post_get_test_portgroup(extra={'vif_port_id': 'foo'})
-        response = self.post_json('/portgroups', pgdict, headers=headers)
-        self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.CREATED, response.status_int)
-        self.assertEqual({'vif_port_id': 'foo'}, response.json['extra'])
-        self.assertEqual({'tenant_vif_port_id': 'foo'},
-                         response.json['internal_info'])
-
-    @mock.patch.object(common_utils, 'warn_about_deprecated_extra_vif_port_id',
-                       autospec=True)
-    def test_create_portgroup_with_extra_vif_port_id(self, mock_warn):
-        headers = {api_base.Version.string: '1.27'}
-        self._test_create_portgroup_with_extra_vif_port_id(headers, mock_warn)
-        self.assertFalse(mock_warn.called)
-
-    @mock.patch.object(common_utils, 'warn_about_deprecated_extra_vif_port_id',
-                       autospec=True)
-    def test_create_portgroup_with_extra_vif_port_id_deprecated(
-            self, mock_warn):
-        self._test_create_portgroup_with_extra_vif_port_id(
-            self.headers, mock_warn)
-        self.assertTrue(mock_warn.called)
-
-    @mock.patch.object(common_utils, 'warn_about_deprecated_extra_vif_port_id',
-                       autospec=True)
-    def test_create_portgroup_with_no_extra(self, mock_warn):
-        pgdict = apiutils.post_get_test_portgroup()
-        del pgdict['extra']
-        response = self.post_json('/portgroups', pgdict, headers=self.headers)
-        self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.CREATED, response.status_int)
-        self.assertEqual(0, mock_warn.call_count)
-
     def test_create_portgroup_no_address(self):
         pdict = apiutils.post_get_test_portgroup()
         del pdict['address']
@@ -1504,7 +1340,7 @@ class TestPost(test_api_base.BaseApiTest):
         self.assertEqual('active-backup', portgroup.mode)
 
 
-@mock.patch.object(rpcapi.ConductorAPI, 'destroy_portgroup')
+@mock.patch.object(rpcapi.ConductorAPI, 'destroy_portgroup', autospec=True)
 class TestDelete(test_api_base.BaseApiTest):
     headers = {api_base.Version.string: str(api_v1.max_version())}
 
@@ -1515,7 +1351,8 @@ class TestDelete(test_api_base.BaseApiTest):
                                                          name='pg.1',
                                                          node_id=self.node.id)
 
-        gtf = mock.patch.object(rpcapi.ConductorAPI, 'get_topic_for')
+        gtf = mock.patch.object(rpcapi.ConductorAPI, 'get_topic_for',
+                                autospec=True)
         self.mock_gtf = gtf.start()
         self.mock_gtf.return_value = 'test-topic'
         self.addCleanup(gtf.stop)
@@ -1527,7 +1364,8 @@ class TestDelete(test_api_base.BaseApiTest):
         self.assertEqual('application/json', response.content_type)
         self.assertIn(self.portgroup.address, response.json['error_message'])
 
-    @mock.patch.object(notification_utils, '_emit_api_notification')
+    @mock.patch.object(notification_utils, '_emit_api_notification',
+                       autospec=True)
     def test_delete_portgroup_byid(self, mock_notify, mock_dpt):
         self.delete('/portgroups/%s' % self.portgroup.uuid,
                     headers=self.headers)
@@ -1541,7 +1379,8 @@ class TestDelete(test_api_base.BaseApiTest):
                                       obj_fields.NotificationStatus.END,
                                       node_uuid=self.node.uuid)])
 
-    @mock.patch.object(notification_utils, '_emit_api_notification')
+    @mock.patch.object(notification_utils, '_emit_api_notification',
+                       autospec=True)
     def test_delete_portgroup_node_locked(self, mock_notify, mock_dpt):
         self.node.reserve(self.context, 'fake', self.node.uuid)
         mock_dpt.side_effect = exception.NodeLocked(node='fake-node',
