@@ -411,14 +411,14 @@ class RegisterInterfacesTestCase(mgr_utils.ServiceSetUpMixin,
         esi_mock.side_effect = [
             collections.OrderedDict((
                 ('management', ['fake', 'noop']),
-                ('deploy', ['agent', 'iscsi']),
+                ('deploy', ['direct', 'ansible']),
             )),
             collections.OrderedDict((
                 ('management', ['fake']),
-                ('deploy', ['agent', 'fake']),
+                ('deploy', ['direct', 'fake']),
             )),
         ]
-        default_mock.side_effect = ('fake', 'agent', 'fake', 'agent')
+        default_mock.side_effect = ('fake', 'direct', 'fake', 'direct')
         expected_calls = [
             mock.call(
                 mock.ANY,
@@ -432,11 +432,11 @@ class RegisterInterfacesTestCase(mgr_utils.ServiceSetUpMixin,
                   'default': False},
                  {'hardware_type': 'fake-hardware',
                   'interface_type': 'deploy',
-                  'interface_name': 'agent',
+                  'interface_name': 'direct',
                   'default': True},
                  {'hardware_type': 'fake-hardware',
                   'interface_type': 'deploy',
-                  'interface_name': 'iscsi',
+                  'interface_name': 'ansible',
                   'default': False},
                  {'hardware_type': 'manual-management',
                   'interface_type': 'management',
@@ -444,7 +444,7 @@ class RegisterInterfacesTestCase(mgr_utils.ServiceSetUpMixin,
                   'default': True},
                  {'hardware_type': 'manual-management',
                   'interface_type': 'deploy',
-                  'interface_name': 'agent',
+                  'interface_name': 'direct',
                   'default': True},
                  {'hardware_type': 'manual-management',
                   'interface_type': 'deploy',
@@ -471,7 +471,7 @@ class RegisterInterfacesTestCase(mgr_utils.ServiceSetUpMixin,
         esi_mock.side_effect = [
             collections.OrderedDict((
                 ('management', ['fake', 'noop']),
-                ('deploy', ['agent', 'iscsi']),
+                ('deploy', ['direct', 'ansible']),
             )),
         ]
         default_mock.side_effect = exception.NoValidDefaultForInterface("boo")
@@ -542,6 +542,12 @@ class StartConsolesTestCase(mgr_utils.ServiceSetUpMixin, db_base.DbTestCase):
                        fields.NotificationStatus.START),
              mock.call(mock.ANY, 'console_restore',
                        fields.NotificationStatus.ERROR)])
+        history = objects.NodeHistory.list_by_node_id(self.context,
+                                                      test_node.id)
+        entry = history[0]
+        self.assertEqual('startup failure', entry['event_type'])
+        self.assertEqual('ERROR', entry['severity'])
+        self.assertIsNotNone(entry['event'])
 
     @mock.patch.object(base_manager, 'LOG', autospec=True)
     def test__start_consoles_node_locked(self, log_mock, mock_notify,
@@ -599,3 +605,9 @@ class MiscTestCase(mgr_utils.ServiceSetUpMixin, db_base.DbTestCase):
         self.service._fail_transient_state(states.DEPLOYING, 'unknown err')
         node.refresh()
         self.assertEqual(states.DEPLOYFAIL, node.provision_state)
+        history = objects.NodeHistory.list_by_node_id(self.context,
+                                                      node.id)
+        entry = history[0]
+        self.assertEqual('transition', entry['event_type'])
+        self.assertEqual('ERROR', entry['severity'])
+        self.assertEqual('unknown err', entry['event'])
