@@ -909,8 +909,8 @@ class DracRedfishManagementTestCase(test_utils.BaseDracTest):
 
     @mock.patch.object(molds, 'get_configuration', autospec=True)
     @mock.patch.object(redfish_utils, 'get_system', autospec=True)
-    def test_import_configuration_incorrect_interface(self, mock_get_system,
-                                                      mock_get_configuration):
+    def test_import_configuration_incorrect_schema(self, mock_get_system,
+                                                   mock_get_configuration):
         task = mock.Mock(node=self.node, context=self.context)
         fake_manager_oem1 = mock.Mock()
         fake_manager1 = mock.Mock()
@@ -920,7 +920,7 @@ class DracRedfishManagementTestCase(test_utils.BaseDracTest):
             '{"oem": {"interface": "idrac-wsman", '
             '"data": {"prop1": "value1", "prop2": 2}}}')
 
-        self.assertRaises(exception.DracOperationError,
+        self.assertRaises(exception.InvalidParameterValue,
                           self.management.import_configuration, task, 'edge')
 
     @mock.patch.object(deploy_utils, 'get_async_step_return_state',
@@ -1088,6 +1088,25 @@ class DracRedfishManagementTestCase(test_utils.BaseDracTest):
             ._check_import_configuration_task
             .assert_called_once_with(task, '/TaskService/123'))
 
+    @mock.patch.object(redfish_utils, 'get_task_monitor', autospec=True)
+    def test__check_import_configuration_task_missing(
+            self, mock_get_task_monitor):
+        mock_get_task_monitor.side_effect = exception.RedfishError(
+            error='Task not found')
+        self.management._set_success = mock.Mock()
+        self.management._set_failed = mock.Mock()
+
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            self.management._check_import_configuration_task(
+                task, '/TaskService/123')
+
+            self.management._set_failed.assert_called_once_with(
+                task, mock.ANY, mock.ANY)
+            self.management._set_success.assert_not_called()
+            self.assertIsNone(
+                task.node.driver_internal_info.get('import_task_monitor_url'))
+
     @mock.patch.object(drac_mgmt.LOG, 'debug', autospec=True)
     @mock.patch.object(redfish_utils, 'get_task_monitor', autospec=True)
     def test__check_import_configuration_task_still_processing(
@@ -1149,6 +1168,83 @@ class DracRedfishManagementTestCase(test_utils.BaseDracTest):
             self.assertIsNone(
                 task.node.driver_internal_info.get('import_task_monitor_url'))
 
+    @mock.patch.object(redfish_utils, 'get_task_monitor', autospec=True)
+    def test__check_import_configuration_task_partial_failed(
+            self, mock_get_task_monitor):
+        driver_internal_info = {'import_task_monitor_url': '/TaskService/123'}
+        self.node.driver_internal_info = driver_internal_info
+        self.node.save()
+
+        mock_message1 = mock.Mock()
+        mock_message1.message_id = 'SYS413'
+        mock_message1.message = 'The operation successfully completed'
+        mock_message1.severity = sushy.SEVERITY_OK
+        mock_message2 = mock.Mock()
+        mock_message2.message_id = 'SYS055'
+        mock_message2.message = 'Firmware upgrade failed'
+        mock_message2.severity = sushy.SEVERITY_CRITICAL
+        mock_import_task = mock.Mock()
+        mock_import_task.task_state = sushy.TASK_STATE_COMPLETED
+        mock_import_task.task_status = sushy.HEALTH_OK
+        mock_import_task.messages = [mock_message1, mock_message2]
+        mock_task_monitor = mock.Mock()
+        mock_task_monitor.is_processing = False
+        mock_task_monitor.get_task.return_value = mock_import_task
+        mock_get_task_monitor.return_value = mock_task_monitor
+
+        self.management._set_success = mock.Mock()
+        self.management._set_failed = mock.Mock()
+
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            self.management._check_import_configuration_task(
+                task, '/TaskService/123')
+
+            self.management._set_failed.assert_called_once_with(
+                task, mock.ANY,
+                "Failed import configuration task: /TaskService/123. Message: "
+                "'Firmware upgrade failed'.")
+            self.management._set_success.assert_not_called()
+            self.assertIsNone(
+                task.node.driver_internal_info.get('import_task_monitor_url'))
+
+    @mock.patch.object(redfish_utils, 'get_task_monitor', autospec=True)
+    def test__check_import_configuration_task_partial_failed_idrac5(
+            self, mock_get_task_monitor):
+        driver_internal_info = {'import_task_monitor_url': '/TaskService/123'}
+        self.node.driver_internal_info = driver_internal_info
+        self.node.save()
+
+        mock_message1 = mock.Mock()
+        mock_message1.message = ('Import of Server Configuration Profile '
+                                 'operation completed with errors')
+        mock_message1.message_id = 'IDRAC.2.4.SYS055'
+        mock_import_task = mock.Mock()
+        mock_import_task.task_state = sushy.TASK_STATE_COMPLETED
+        mock_import_task.task_status = sushy.HEALTH_OK
+        mock_import_task.messages = [mock_message1]
+        mock_task_monitor = mock.Mock()
+        mock_task_monitor.is_processing = False
+        mock_task_monitor.get_task.return_value = mock_import_task
+        mock_get_task_monitor.return_value = mock_task_monitor
+
+        self.management._set_success = mock.Mock()
+        self.management._set_failed = mock.Mock()
+
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            self.management._check_import_configuration_task(
+                task, '/TaskService/123')
+
+            self.management._set_failed.assert_called_once_with(
+                task, mock.ANY,
+                "Failed import configuration task: /TaskService/123. Message: "
+                "'Import of Server Configuration Profile "
+                "operation completed with errors'.")
+            self.management._set_success.assert_not_called()
+            self.assertIsNone(
+                task.node.driver_internal_info.get('import_task_monitor_url'))
+
     @mock.patch.object(redfish_utils, 'get_task_monitor', autospec=True)
     def test__check_import_configuration_task(self, mock_get_task_monitor):
         driver_internal_info = {'import_task_monitor_url': '/TaskService/123'}
@@ -1156,7 +1252,9 @@ class DracRedfishManagementTestCase(test_utils.BaseDracTest):
         self.node.save()
 
         mock_message = mock.Mock()
+        mock_message.message_id = 'SYS413'
         mock_message.message = 'Configuration import done'
+        mock_message.severity = sushy.SEVERITY_OK
         mock_import_task = mock.Mock()
         mock_import_task.task_state = sushy.TASK_STATE_COMPLETED
         mock_import_task.task_status = sushy.HEALTH_OK
@@ -1189,7 +1287,9 @@ class DracRedfishManagementTestCase(test_utils.BaseDracTest):
         self.node.save()
 
         mock_message = mock.Mock()
+        mock_message.message_id = 'SYS413'
         mock_message.message = 'Configuration import done'
+        mock_message.severity = sushy.SEVERITY_OK
         mock_import_task = mock.Mock()
         mock_import_task.task_state = sushy.TASK_STATE_COMPLETED
         mock_import_task.task_status = sushy.HEALTH_OK
@@ -1232,7 +1332,9 @@ class DracRedfishManagementTestCase(test_utils.BaseDracTest):
         self.node.save()
 
         mock_message = mock.Mock()
+        mock_message.message_id = 'SYS413'
         mock_message.message = 'Configuration import done'
+        mock_message.severity = sushy.SEVERITY_OK
         mock_import_task = mock.Mock()
         mock_import_task.task_state = sushy.TASK_STATE_COMPLETED
         mock_import_task.task_status = sushy.HEALTH_OK
@@ -1360,3 +1462,43 @@ class DracRedfishManagementTestCase(test_utils.BaseDracTest):
             mock_manager_oem.job_service.delete_jobs.assert_called_once_with(
                 job_ids=['JID_CLEARALL'])
             mock_manager_oem.reset_idrac.assert_called_once_with()
+
+    def test__validate_conf_mold(self):
+        drac_mgmt._validate_conf_mold({'oem': {'interface': 'idrac-redfish',
+                                       'data': {'SystemConfiguration': {}}}})
+
+    def test__validate_conf_mold_oem_missing(self):
+        self.assertRaisesRegex(
+            exception.InvalidParameterValue,
+            "'oem' is a required property",
+            drac_mgmt._validate_conf_mold,
+            {'bios': {'reset': False}})
+
+    def test__validate_conf_mold_interface_missing(self):
+        self.assertRaisesRegex(
+            exception.InvalidParameterValue,
+            "'interface' is a required property",
+            drac_mgmt._validate_conf_mold,
+            {'oem': {'data': {'SystemConfiguration': {}}}})
+
+    def test__validate_conf_mold_interface_not_supported(self):
+        self.assertRaisesRegex(
+            exception.InvalidParameterValue,
+            "'idrac-redfish' was expected",
+            drac_mgmt._validate_conf_mold,
+            {'oem': {'interface': 'idrac-wsman',
+             'data': {'SystemConfiguration': {}}}})
+
+    def test__validate_conf_mold_data_missing(self):
+        self.assertRaisesRegex(
+            exception.InvalidParameterValue,
+            "'data' is a required property",
+            drac_mgmt._validate_conf_mold,
+            {'oem': {'interface': 'idrac-redfish'}})
+
+    def test__validate_conf_mold_data_empty(self):
+        self.assertRaisesRegex(
+            exception.InvalidParameterValue,
+            "does not have enough properties",
+            drac_mgmt._validate_conf_mold,
+            {'oem': {'interface': 'idrac-redfish', 'data': {}}})
