@@ -172,6 +172,8 @@ class IloInspectTestCase(test_common.BaseIloTest):
 
     @mock.patch.object(ilo_inspect.LOG, 'warning',
                        spec_set=True, autospec=True)
+    @mock.patch.object(ilo_inspect, '_get_security_parameters',
+                       spec_set=True, autospec=True)
     @mock.patch.object(ilo_inspect, '_get_capabilities', spec_set=True,
                        autospec=True)
     @mock.patch.object(inspect_utils, 'create_ports_if_not_exist',
@@ -187,21 +189,26 @@ class IloInspectTestCase(test_common.BaseIloTest):
                               get_essential_mock,
                               create_port_mock,
                               get_capabilities_mock,
+                              get_security_params_mock,
                               log_mock):
         ilo_object_mock = get_ilo_object_mock.return_value
         properties = {'memory_mb': '512', 'local_gb': 10,
                       'cpus': '1', 'cpu_arch': 'x86_64'}
         macs = {'NIC.LOM.1.1': 'aa:aa:aa:aa:aa:aa'}
         capabilities = {'server_model': 'Gen10'}
+        security_params = (
+            {'security_parameters': {'Password Complexity': 'ok'}})
         result = {'properties': properties, 'macs': macs}
         get_essential_mock.return_value = result
         get_capabilities_mock.return_value = capabilities
+        get_security_params_mock.return_value = security_params
         power_mock.return_value = states.POWER_ON
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=False) as task:
-            expected_properties = {'memory_mb': '512', 'local_gb': 10,
-                                   'cpus': '1', 'cpu_arch': 'x86_64',
-                                   'capabilities': 'server_model:Gen10'}
+            expected_properties = {
+                'memory_mb': '512', 'local_gb': 10, 'cpus': '1',
+                'cpu_arch': 'x86_64', 'capabilities': 'server_model:Gen10',
+                'security_parameters': {'Password Complexity': 'ok'}}
             task.driver.inspect.inspect_hardware(task)
             self.assertEqual(expected_properties, task.node.properties)
             power_mock.assert_called_once_with(mock.ANY, task)
