@@ -1,5 +1,6 @@
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 # All Rights Reserved.
+# Copyright (c) 2021 Dell Inc. or its subsidiaries.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -27,6 +28,7 @@ Current list of mocked libraries:
 - scciclient
 - python-dracclient
 - python-ibmcclient
+- sushy_oem_idrac
 """
 
 import importlib
@@ -122,6 +124,19 @@ if not dracclient:
     if 'ironic.drivers.modules.drac' in sys.modules:
         importlib.reload(sys.modules['ironic.drivers.modules.drac'])
 
+sushy_oem_idrac = importutils.try_import('sushy_oem_idrac')
+if not sushy_oem_idrac:
+    raidmode = mock.sentinel.PHYSICAL_DISK_STATE_MODE_RAID
+    nonraidmode = mock.sentinel.PHYSICAL_DISK_STATE_MODE_NONRAID
+    sushy_oem_idrac = mock.MagicMock(
+        spec_set=mock_specs.SUSHY_OEM_IDRAC_MOD_SPEC,
+        PHYSICAL_DISK_STATE_MODE_RAID=raidmode,
+        PHYSICAL_DISK_STATE_MODE_NONRAID=nonraidmode,
+        JOB_TYPE_RT_NO_REBOOT_CONF=mock.sentinel.JOB_TYPE_RT_NO_REBOOT_CONF,
+        JOB_TYPE_RAID_CONF=mock.sentinel.JOB_TYPE_RAID_CONF
+    )
+
+    sys.modules['sushy_oem_idrac'] = sushy_oem_idrac
 
 # attempt to load the external 'pysnmp' library, which is required by
 # the optional drivers.modules.snmp module
@@ -228,7 +243,10 @@ if not sushy:
         HEALTH_WARNING='warning',
         SECURE_BOOT_RESET_KEYS_TO_DEFAULT="ResetAllKeysToDefault",
         SECURE_BOOT_RESET_KEYS_DELETE_ALL="DeleteAllKeys",
-        VOLUME_TYPE_RAW_DEVICE='rawdevice'
+        VOLUME_TYPE_RAW_DEVICE='rawdevice',
+        SEVERITY_OK='ok',
+        SEVERITY_WARNING='warning',
+        SEVERITY_CRITICAL='critical'
     )
 
     sys.modules['sushy'] = sushy
