@@ -61,6 +61,18 @@ class TestNodeObject(db_base.DbTestCase, obj_utils.SchemasTestMixIn):
         # Ensure the node can be serialised.
         jsonutils.dumps(d)
 
+    def test_as_dict_secure_configdrive_as_dict(self):
+        self.node.driver_info['ipmi_password'] = 'fake'
+        self.node.instance_info['configdrive'] = {'user_data': 'data'}
+        self.node.driver_internal_info['agent_secret_token'] = 'abc'
+        d = self.node.as_dict(secure=True)
+        self.assertEqual('******', d['driver_info']['ipmi_password'])
+        self.assertEqual('******', d['instance_info']['configdrive'])
+        self.assertEqual('******',
+                         d['driver_internal_info']['agent_secret_token'])
+        # Ensure the node can be serialised.
+        jsonutils.dumps(d)
+
     def test_as_dict_secure_with_configdrive(self):
         self.node.driver_info['ipmi_password'] = 'fake'
         self.node.instance_info['configdrive'] = 'data'
@@ -73,6 +85,19 @@ class TestNodeObject(db_base.DbTestCase, obj_utils.SchemasTestMixIn):
         # Ensure the node can be serialised.
         jsonutils.dumps(d)
 
+    def test_as_dict_secure_with_configdrive_as_dict(self):
+        self.node.driver_info['ipmi_password'] = 'fake'
+        self.node.instance_info['configdrive'] = {'user_data': 'data'}
+        self.node.driver_internal_info['agent_secret_token'] = 'abc'
+        d = self.node.as_dict(secure=True, mask_configdrive=False)
+        self.assertEqual('******', d['driver_info']['ipmi_password'])
+        self.assertEqual({'user_data': 'data'},
+                         d['instance_info']['configdrive'])
+        self.assertEqual('******',
+                         d['driver_internal_info']['agent_secret_token'])
+        # Ensure the node can be serialised.
+        jsonutils.dumps(d)
+
     def test_as_dict_with_traits(self):
         self.fake_node['traits'] = ['CUSTOM_1']
         self.node = obj_utils.get_test_node(self.ctxt, **self.fake_node)
@@ -371,6 +396,67 @@ class TestNodeObject(db_base.DbTestCase, obj_utils.SchemasTestMixIn):
             self.assertThat(nodes, matchers.HasLength(1))
             self.assertIsInstance(nodes[0], objects.Node)
             self.assertEqual(self.context, nodes[0]._context)
+            self.assertIsInstance(nodes[0].traits, objects.TraitList)
+
+    def test_list_with_fields(self):
+        with mock.patch.object(self.dbapi, 'get_node_list',
+                               autospec=True) as mock_get_list:
+            mock_get_list.return_value = [self.fake_node]
+            nodes = objects.Node.list(self.context,
+                                      fields=['name', 'uuid',
+                                              'provision_state'])
+            mock_get_list.assert_called_with(
+                filters=None, limit=None, marker=None, sort_key=None,
+                sort_dir=None,
+                fields=['id', 'name', 'uuid', 'provision_state', 'version',
+                        'updated_at', 'created_at', 'owner', 'lessee',
+                        'driver', 'conductor_group'])
+            self.assertThat(nodes, matchers.HasLength(1))
+            self.assertEqual(self.fake_node['uuid'], nodes[0].uuid)
+            self.assertEqual(self.fake_node['provision_state'],
+                             nodes[0].provision_state)
+            # Random assortment of fields which should not be present.
+            for field in ['power_state', 'instance_info', 'resource_class',
+                          'automated_clean', 'properties', 'driver', 'traits']:
+                self.assertFalse(field not in dir(nodes[0]))
+
+    def test_list_with_fields_traits(self):
+        with mock.patch.object(self.dbapi, 'get_node_list',
+                               autospec=True) as mock_get_list:
+            # Trait objects and ultimately rows have an underlying
+            # version. Since we've never changed it, it should just
+            # be one, but this is required for the oslo versioned
+            # objects code path to handle objects properly and
+            # navigate mid-upgrade cases.
+            self.fake_node['traits'] = [{
+                'trait': 'traitx', 'version': "1"}]
+            mock_get_list.return_value = [self.fake_node]
+            nodes = objects.Node.list(self.context,
+                                      fields=['uuid', 'provision_state',
+                                              'traits'])
+            self.assertThat(nodes, matchers.HasLength(1))
+            self.assertEqual(self.fake_node['uuid'], nodes[0].uuid)
+            self.assertEqual(self.fake_node['provision_state'],
+                             nodes[0].provision_state)
+            self.assertIsInstance(nodes[0].traits, objects.TraitList)
+            self.assertEqual('traitx', nodes[0].traits[0].trait)
+            for field in ['power_state', 'instance_info', 'resource_class',
+                          'automated_clean', 'properties', 'driver']:
+                self.assertFalse(field not in dir(nodes[0]))
+
+    def test_list_with_fields_empty_trait_present(self):
+        with mock.patch.object(self.dbapi, 'get_node_list',
+                               autospec=True) as mock_get_list:
+            mock_get_list.return_value = [self.fake_node]
+            nodes = objects.Node.list(self.context,
+                                      fields=['uuid', 'provision_state',
+                                              'traits'])
+            self.assertThat(nodes, matchers.HasLength(1))
+            self.assertEqual(self.fake_node['uuid'], nodes[0].uuid)
+            self.assertEqual(self.fake_node['provision_state'],
+                             nodes[0].provision_state)
+            self.assertIsInstance(nodes[0].traits, objects.TraitList)
+            self.assertIn('traits', nodes[0])
 
     def test_reserve(self):
         with mock.patch.object(self.dbapi, 'reserve_node',
@@ -1206,6 +1292,81 @@ class TestConvertToVersion(db_base.DbTestCase):
         self.assertIsNone(node.lessee)
         self.assertEqual({}, node.obj_get_changes())
 
+    def test_boot_mode_supported_missing(self):
+        # boot_mode and secure_boot not set, should be set to default.
+        node = obj_utils.get_test_node(self.ctxt, **self.fake_node)
+        delattr(node, 'boot_mode')
+        delattr(node, 'secure_boot')
+        node.obj_reset_changes()
+        node._convert_to_version("1.36")
+        self.assertIsNone(node.boot_mode)
+        self.assertIsNone(node.secure_boot)
+        self.assertEqual({'boot_mode': None,
+                          'secure_boot': None},
+                         node.obj_get_changes())
+
+    def test_boot_mode_supported_set(self):
+        # boot_mode and secure_boot set, no change required.
+        node = obj_utils.get_test_node(self.ctxt, **self.fake_node)
+
+        node.boot_mode = "uefi"
+        node.secure_boot = True
+        node.obj_reset_changes()
+        node._convert_to_version("1.36")
+        self.assertEqual("uefi", node.boot_mode)
+        self.assertTrue(node.secure_boot)
+        self.assertEqual({}, node.obj_get_changes())
+
+    def test_boot_mode_unsupported_missing(self):
+        # boot_mode and secure_boot not set, no change required.
+        node = obj_utils.get_test_node(self.ctxt, **self.fake_node)
+
+        delattr(node, 'boot_mode')
+        delattr(node, 'secure_boot')
+        node.obj_reset_changes()
+        node._convert_to_version("1.35")
+        self.assertNotIn('boot_mode', node)
+        self.assertNotIn('secure_boot', node)
+        self.assertEqual({}, node.obj_get_changes())
+
+    def test_boot_mode_unsupported_set_remove(self):
+        # boot_mode and secure_boot set, should be removed.
+        node = obj_utils.get_test_node(self.ctxt, **self.fake_node)
+
+        node.boot_mode = "uefi"
+        node.secure_boot = True
+        node.obj_reset_changes()
+        node._convert_to_version("1.35")
+        self.assertNotIn('boot_mode', node)
+        self.assertNotIn('secure_boot', node)
+        self.assertEqual({}, node.obj_get_changes())
+
+    def test_boot_mode_unsupported_set_no_remove_non_default(self):
+        # boot_mode and secure_boot set, should be set to default.
+        node = obj_utils.get_test_node(self.ctxt, **self.fake_node)
+
+        node.boot_mode = "uefi"
+        node.secure_boot = True
+        node.obj_reset_changes()
+        node._convert_to_version("1.35", False)
+        self.assertIsNone(node.boot_mode)
+        self.assertIsNone(node.secure_boot)
+        self.assertEqual({'boot_mode': None,
+                          'secure_boot': None},
+                         node.obj_get_changes())
+
+    def test_boot_mode_unsupported_set_no_remove_default(self):
+        # boot_mode and secure_boot set, no change required.
+        node = obj_utils.get_test_node(self.ctxt, **self.fake_node)
+
+        node.boot_mode = None
+        node.secure_boot = None
+        node.obj_reset_changes()
+        node._convert_to_version("1.35", False)
+        self.assertIsNone(node.boot_mode)
+        self.assertIsNone(node.secure_boot)
+        self.assertEqual({}, node.obj_get_changes())
+
 
 class TestNodePayloads(db_base.DbTestCase):
 
@@ -1222,6 +1383,8 @@ class TestNodePayloads(db_base.DbTestCase):
         self.assertEqual(self.node.created_at, payload.created_at)
         self.assertEqual(self.node.driver, payload.driver)
         self.assertEqual(self.node.extra, payload.extra)
+        self.assertEqual(self.node.boot_mode, payload.boot_mode)
+        self.assertEqual(self.node.secure_boot, payload.secure_boot)
         self.assertEqual(self.node.inspection_finished_at,
                          payload.inspection_finished_at)
         self.assertEqual(self.node.inspection_started_at,
